==> Botan-1.1.1.tgz: Botan-1.1.1/include/rw.h <==
/*************************************************
* Rabin-Williams Header File                     *
* (C) 1999-2002 The Botan Project                *
*************************************************/

#ifndef BOTAN_RW_H__
#define BOTAN_RW_H__

#include <botan/if_algo.h>
#include <botan/pk_keys.h>

namespace Botan {

/*************************************************
* Rabin-Williams Public Key                      *
*************************************************/
class RW_PublicKey : public PK_Verifying_with_MR_Key,
                     public virtual IF_Scheme_PublicKey
   {
   public:
      SecureVector<byte> verify(const byte[], u32bit) const;

      u32bit max_input_bits() const { return (n.bits() - 1); }

      RW_PublicKey(const BigInt&, const BigInt&);
   protected:
      RW_PublicKey() { }
   private:
      std::string algo_name() const { return "RW"; }
      BigInt public_op(const BigInt&) const;
   };

/*************************************************
* Rabin-Williams Private Key                     *
*************************************************/
class RW_PrivateKey : public RW_PublicKey, public PK_Signing_Key,
                      public IF_Scheme_PrivateKey
   {
   public:
      SecureVector<byte> sign(const byte[], u32bit) const;

      bool check_params() const;

      RW_PrivateKey(const BigInt&, const BigInt&, const BigInt&,
                    const BigInt& = 0, const BigInt& = 0);
      RW_PrivateKey(u32bit, const BigInt& = 2);
   private:
      BigInt private_op(const BigInt&) const;
   };

}

#endif

==> Botan-1.1.2.tgz: Botan-1.1.2/include/rw.h <==
/*************************************************
* Rabin-Williams Header File                     *
* (C) 1999-2002 The Botan Project                *
*************************************************/

#ifndef BOTAN_RW_H__
#define BOTAN_RW_H__

#include <botan/if_algo.h>
#include <botan/pk_keys.h>

namespace Botan {

/*************************************************
* Rabin-Williams Public Key                      *
*************************************************/
class RW_PublicKey : public PK_Verifying_with_MR_Key,
                     public virtual IF_Scheme_PublicKey
   {
   public:
      SecureVector<byte> verify(const byte[], u32bit) const;

      u32bit max_input_bits() const { return (n.bits() - 1); }

      RW_PublicKey(const BigInt&, const BigInt&);
      RW_PublicKey(DataSource&, X509_Encoding = PEM);
   protected:
      RW_PublicKey() {}
   private:
      std::string algo_name() const { return "Rabin-Williams"; }
      BigInt public_op(const BigInt&) const;
   };

/*************************************************
* Rabin-Williams Private Key                     *
*************************************************/
class RW_PrivateKey : public RW_PublicKey, public PK_Signing_Key,
                      public IF_Scheme_PrivateKey
   {
   public:
      SecureVector<byte> sign(const byte[], u32bit) const;

      bool check_params() const;

      RW_PrivateKey(const BigInt&, const BigInt&, const BigInt&,
                    const BigInt& = 0, const BigInt& = 0);
      RW_PrivateKey(u32bit, const BigInt& = 2);
      RW_PrivateKey(DataSource&, const std::string& = "", X509_Encoding = PEM);
   private:
      BigInt private_op(const BigInt&) const;
   };

}

#endif
